/*-
 * Copyright (C) 2001,2002 Juergen Keil.
 * Copyright (C) 2001,2002 TooLs GmbH.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by TooLs GmbH.
 * 4. The name of TooLs GmbH may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY TOOLS GMBH ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL TOOLS GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/audio.h>
#include "audioi810.h"


static void
usage()
{
    fprintf(stderr, 
	    "i810ctl [-d device] [-b beep-vol] [-p pcm-vol] "
	    "[-l status] [-s status] [-3 status] [-C center] [-D depth]\n"
	    "\t-l enable/disable loudness (bass boost), status = on/off/0/1\n"
	    "\t-s enable/disable simulated stereo enhancement, status = on/off/0/1\n"
	    "\t-3 enable/disable 3D stereo enhancement, status = on/off/0/1\n"
	    "\t-D 3D stereo depth\n"
	    "\t-C 3D stereo center depth\n"
	);
    exit(2);
}


int
main(int argc, char **argv)
{
    int c;
    char *device_name = "/dev/audioctl";
    int au;
    int beep_vol = -1;
    int pcm_vol = -1;
    int enable_loudness = -1;
    int enable_st = -1;
    int enable_3d = -1;
    int depth = -1;
    int center = -1;

    while ((c = getopt(argc, argv, "d:b:p:l:s:3:D:C:")) != -1) {
	switch (c) {
	case 'd':
	    device_name = optarg;
	    break;
	case 'b':
	    beep_vol = atoi(optarg);
	    break;
	case 'p':
	    pcm_vol = atoi(optarg);
	    break;
	case '3':
	    if (strcmp(optarg, "on") == 0)
		enable_3d = 1;
	    else if (strcmp(optarg, "off") == 0)
		enable_3d = 0;
	    else 
		enable_3d = atoi(optarg);
	    break;
	case 'C':
	    center = atoi(optarg);
	    break;
	case 'D':
	    depth = atoi(optarg);
	    break;
	case 'l':
	    if (strcmp(optarg, "on") == 0)
		enable_loudness = 1;
	    else if (strcmp(optarg, "off") == 0)
		enable_loudness = 0;
	    else 
		enable_loudness = atoi(optarg);
	    break;
	case 's':
	    if (strcmp(optarg, "on") == 0)
		enable_st = 1;
	    else if (strcmp(optarg, "off") == 0)
		enable_st = 0;
	    else 
		enable_st = atoi(optarg);
	    break;
	default:
	    usage();
	}
    }

    au = open(device_name, O_RDWR);
    if (au < 0) {
	perror(device_name);
	exit(1);
    }
    if (pcm_vol != -1) {
	if (ioctl(au, AUDIOI810_SET_PCMOUT_VOL, pcm_vol)) 
	    perror("cannot set pc beep volume");
    }
    if (beep_vol != -1) {
	if (ioctl(au, AUDIOI810_SET_BEEP_VOL, beep_vol))
	    perror("cannot set pcm output volume");
    }
    if (enable_loudness != -1) {
	if (ioctl(au, AUDIOI810_SET_LOUDNESS_ENABLE, enable_loudness))
	    perror("cannot enable/disable loudness");
    }
    if (enable_st != -1) {
	if (ioctl(au, AUDIOI810_SET_STEREO_ENHANCE_ENABLE, enable_st))
	    perror("cannot enable/disable stereo enhance mode");
    }
    if (enable_3d != -1) {
	if (ioctl(au, AUDIOI810_SET_3D_STEREO_ENABLE, enable_3d))
	    perror("cannot enable/disable 3d stereo mode");
    }
    if (depth != -1) {
	if (ioctl(au, AUDIOI810_SET_3D_STEREO_DEPTH, depth))
	    perror("cannot set 3d stereo depth");
    }
    if (center != -1) {
	if (ioctl(au, AUDIOI810_SET_3D_STEREO_CENTER, depth))
	    perror("cannot set 3d stereo center");
    }
    close(au);

    return 0;
}
