/*-
 * Copyright (C) 2002 Juergen Keil.
 * Copyright (C) 2002 TooLs GmbH.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by TooLs GmbH.
 * 4. The name of TooLs GmbH may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY TOOLS GMBH ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL TOOLS GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#include "audio_codec.h"

struct ac97_codec_ops {
    int (*ac97_read) (void *, uint16_t sub_addr, uint16_t *data);
    int (*ac97_write)(void *, uint16_t sub_addr, uint16_t value);
};


#define	AC97_READ(acm, addr, data)					\
	((acm)->ac97_ops->ac97_read((acm)->ac97_data, (addr), (data)))
#define	AC97_WRITE(acm, addr, data)					\
	((acm)->ac97_ops->ac97_write((acm)->ac97_data, (addr), (data)))

struct ac97_codec {
    struct audio_codec	base;

    audiohdl_t		audio_handle;
    struct ac97_codec_ops *ac97_ops;
    void	       *ac97_data;


    uint8_t             ac97_pcmvol;
    uint8_t             ac97_mic_20db_boost;
    int8_t		ac97_eapd;
    uint8_t             ac97_mvol_max;  /* maximum ac97 master-volume value:
                                         * 0x1f: 5-bit ac97 mixer
                                         * 0x3f: 6-bit ac97 mixer
                                         */
    uint8_t		ac97_auxout;	/* type of auxout port */
    uint8_t		ac97_rev;	/* ac'97 codec rev */
    uint8_t		ad1980;

    audio_info_t        audio_info;     /* driver local audio state. Note: */
                                        /* we maintain only a few fields */
                                        /* of the structure in the driver */
};

/* values for ac97_auxout field */
#define	AUX_LNLVL_OUT	0		/* true line level output */
#define	AUX_HP_OUT	1		/* headphone output */
#define	AUX_4CH_OUT	2		/* 4 channel surround sound */

extern audio_codec_handle_t ac97_codec_init(audiohdl_t, struct ac97_codec_ops *, void *);

extern int ac97_codec_play_vol(int vol, int maxvol, int codec_max);
