/*-
 * Copyright (C) 2001 Juergen Keil.
 * Copyright (C) 2001 TooLs GmbH.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by TooLs GmbH.
 * 4. The name of TooLs GmbH may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY TOOLS GMBH ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL TOOLS GMBH BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/audio.h>
#include "audiovia8233.h"


static void
usage()
{
    fprintf(stderr, "v8233ctl [-d device] [-b beep-vol] [-p pcm-vol] [-v vsr-vol]\n");
    exit(2);
}


int
main(int argc, char **argv)
{
    int c;
    char *device_name = "/dev/audioctl";
    int au;
    int beep_vol = -1;
    int pcm_vol = -1;
    int vsr_vol = -1;

    while ((c = getopt(argc, argv, "d:b:p:v:")) != -1) {
	switch (c) {
	case 'd':
	    device_name = optarg;
	    break;
	case 'b':
	    beep_vol = atoi(optarg);
	    break;
	case 'p':
	    pcm_vol = atoi(optarg);
	    break;
	case 'v':
	    vsr_vol = atoi(optarg);
	    break;
	default:
	    usage();
	}
    }

    au = open(device_name, O_RDWR);
    if (au < 0) {
	perror(device_name);
	exit(1);
    }
#if 0
    if (pcm_vol != -1) {
	if (ioctl(au, AUDIOV8233_SET_PCMOUT_VOL, pcm_vol)) 
	    perror("cannot set pc beep volume");
    }
    if (beep_vol != -1) {
	if (ioctl(au, AUDIOV8233_SET_BEEP_VOL, beep_vol))
	    perror("cannot set pcm output volume");
    }
#endif
    if (vsr_vol != -1) {
	if (ioctl(au, AUDIOV8233_SET_VSR_VOL, vsr_vol))
	    perror("cannot set sample rate converter volume");
    }
    close(au);

    return 0;
}
