#ifndef audiohlp_convert_h
#define audiohlp_convert_h

struct device_format {
    uint_t channels;        /* number of interleaved channels */
    uint_t precision;       /* bit-width of each sample */
    uint_t encoding;        /* data encoding method */
    uint_t sample_rate;
};
typedef struct device_format device_format_t;


#define	MAX_CHANNELS 2

typedef int32_t sample_t;

typedef sample_t (*get_sample_func)(void**);
typedef void (*put_sample_func)(void **, sample_t);

struct conv_ctx {
	int no_conv;			/* no conversion needed at all */
	int no_src;			/* no sample rate conversio needed */

    	device_format_t src_fmt;
	device_format_t dst_fmt;

	int src_shift;
	int dst_shift;

	get_sample_func	src_get_sample;
	put_sample_func dst_put_sample;

	sample_t last_sample[MAX_CHANNELS];
	sample_t cur_sample[MAX_CHANNELS];

	int base_freq;
	int src_step;
	int dst_step;
	int pos;
};

extern void convert_init(struct conv_ctx *cctx,
			 device_format_t *destfmt,
			 device_format_t *srcfmt);
extern void convert_cleanup(struct conv_ctx *cctx);
extern void convert_samples(struct conv_ctx *cctx,
			    void *dest, int dest_samples, int *ret_dest_samples,
			    void *src,  int src_samples,  int *ret_src_samples);
#endif
